@@ -449,7 +449,8 @@ class Table(metaclass=MetaTable):
 
         #return cls.type(**params)
     @classmethod
-    def get(cls, id):
+    def get(cls, id, filter={}):
+        filter = cls.where(filter)
         join = Join(cls)
         try:
             db = cls.get_db()
@@ -457,8 +458,8 @@ class Table(metaclass=MetaTable):
             cursor.execute(f"""SELECT {join.select()}
                              FROM {cls}
                              {join}
-                             WHERE {cls(cls.id)}=%s""",
-                             (id,))
+                             WHERE {cls(cls.id)}=%s AND {filter.fields()}""",
+                             [id,]+filter.values())
             if cursor.rowcount > 0:
                 join.row.data(cursor.fetchone())
                 return join.create()
